<?php

declare(strict_types=1);

namespace App\Service;

use App\Enum\SystemSettingKey;
use App\Repository\SystemConfigRepository;

readonly class ConfigurationService
{
    public function __construct(
        private SystemConfigRepository $systemConfigRepository,
    ) {}

    public function get(SystemSettingKey $key): string
    {
        return $this->systemConfigRepository->findByKey($key)->getValue();
    }

    public function set(SystemSettingKey $key, string $value): void
    {
        $config = $this->systemConfigRepository->findByKey($key);
        if ($config->getValue() === $value) {
            return;
        }

        $config->setValue($value);
        $this->systemConfigRepository->save($config);
    }
    public function reset(SystemSettingKey $key): void
    {
        $this->set($key, $key->defaultValue());
    }

    public function resetAll(): void
    {
        foreach (SystemSettingKey::cases() as $key) {
            $this->reset($key);
        }
    }
}
